@@ -624,12 +624,17 @@ def get_ebs_daily_breakdown(days: int = 30, specific_date: str = None, month: st
                 usage_type = group['Keys'][1]
                 cost = float(group['Metrics']['BlendedCost']['Amount'])
                 
-                # Capture ALL EBS-related usage types with meaningful costs
-                if cost >= 0.005 and 'EBS:' in usage_type:
-                    # Use the actual usage type name, cleaned up
-                    clean_type = usage_type.replace('EBS:', '').strip()
-                    display_name = f'EBS {clean_type}'
-                    ebs_costs[display_name] = ebs_costs.get(display_name, 0) + cost
+                # Capture ALL usage types with any measurable cost (EBS and non-EBS gp3)
+                if cost >= 0.0001:
+                    if 'EBS:' in usage_type:
+                        # Standard EBS usage types
+                        clean_type = usage_type.replace('EBS:', '').strip()
+                        display_name = f'EBS {clean_type}'
+                        ebs_costs[display_name] = ebs_costs.get(display_name, 0) + cost
+                    elif 'gp3' in usage_type.lower() and ('provisioned' in usage_type.lower() or 'throughput' in usage_type.lower() or 'iops' in usage_type.lower()):
+                        # Capture gp3 provisioned charges that might not have EBS: prefix
+                        display_name = f'EBS {usage_type}'
+                        ebs_costs[display_name] = ebs_costs.get(display_name, 0) + cost
         
         breakdown = [{'category': cat, 'cost': cost} 
                     for cat, cost in sorted(ebs_costs.items(), key=lambda x: x[1], reverse=True)]
@@ -696,7 +701,7 @@ def get_ec2_daily_breakdown(days: int = 30, specific_date: str = None, month: st
                 cost = float(group['Metrics']['BlendedCost']['Amount'])
                 
                 # Only capture usage types that belong to EC2-related services
-                if cost >= 0.005 and 'EBS:' not in usage_type and 'BoxUsage' not in usage_type:
+                if cost >= 0.0001 and 'EBS:' not in usage_type and 'BoxUsage' not in usage_type:
                     # Filter to only EC2-related services
                     if service in ['Amazon Elastic Compute Cloud - Compute', 'EC2 - Other', 'Amazon Elastic Compute Cloud NatGateway']:
                         # Use the actual usage type name as the display name
