@@ -177,7 +177,12 @@ def output_cost_data_text(days: int = 30, hide_account: bool = False, force_refr
                         is_last_breakdown = (j == len(breakdown_items) - 1)
                         breakdown_prefix = "└──" if is_last_breakdown else "├──"
                         
-                        print(f"    {breakdown_prefix} {category:<47}    {breakdown_prefix} {item_cost:>8.2f}")
+                        # Show more decimal places for very small costs
+                        if item_cost < 0.01:
+                            cost_str = f"{item_cost:>8.4f}"
+                        else:
+                            cost_str = f"{item_cost:>8.2f}"
+                        print(f"    {breakdown_prefix} {category:<47}    {breakdown_prefix} {cost_str}")
             print("=" * 74)
             print(f"TOTAL COST: ${total_cost:>8.2f}")
             print("=" * 74)
